#######
rCDS
#######

.. image:: https://github.com/redpwn/rCDS/workflows/CI/badge.svg
    :target: https://github.com/redpwn/rCDS/actions?query=workflow%3ACI+branch%3Amaster
    :alt: CI Status

.. image:: https://img.shields.io/codecov/c/gh/redpwn/rcds
    :target: https://codecov.io/gh/redpwn/rCDS
    :alt: Coverage

rCDS is RedpwnCTF's automated challenge management and deployment tool. It is
developed and maintained by the `redpwn <https://redpwn.net>`_ CTF team.
